import { Api } from '@openstapps/gitlab-api';
import { Project } from '@openstapps/gitlab-api/lib/types';
/**
 * Tidy issues without milestone
 *
 * This will set the milestone of issues without milestone to 'Meeting'.
 *
 * @param api GitLab API instance to use for the requests
 */
export declare function tidyIssuesWithoutMilestone(api: Api): Promise<void>;
/**
 * Tidy open issues without meeting label
 *
 * This adds the label 'meeting' to all open issues that do not have this label.
 *
 * @param api GitLab API instante to use for requests
 */
export declare function tidyOpenIssuesWithoutMeetingLabel(api: Api): Promise<void>;
/**
 * Tidy labels in a list of projects
 *
 * @param api GitLab API instance to use for the requests
 * @param projects List of projects to tidy labels on
 */
export declare function tidyLabels(api: Api, projects: Project[]): Promise<void>;
/**
 * Tidy milestones in a list of projects
 *
 * @param api GitLab API instance to use for the requests
 * @param projects List of projects to tidy milestones on
 */
export declare function tidyMilestones(api: Api, projects: Project[]): Promise<void>;
/**
 * Tidy protected branches in a list of projects
 *
 * @param api GitLab API instance to use for the requests
 * @param projects List of projects to tidy milestones on
 */
export declare function tidyProtectedBranches(api: Api, projects: Project[]): Promise<void>;
/**
 * Tidy "sub" group members
 *
 * @param api GitLab API instance to use for the requests
 */
export declare function tidySubGroupMembers(api: Api): Promise<void>;
/**
 * Tidy issues without assignee
 *
 * Set assignee to author if no assignee is set.
 *
 * @param api
 */
export declare function tidyIssuesWithoutAssignee(api: Api): Promise<void>;
/**
 * Tidy
 *
 * @param api GitLab API instance to use for the requests
 */
export declare function tidy(api: Api): Promise<void>;
